@@ -1,4 +1,4 @@
-"ensembleSize.ensembleData" <-
+`ensembleSize.ensembleData` <-
 function(x) 
 { 
  attr(x, "ensembleSize")
